@@ -28,6 +28,8 @@ EasyBuild support for gimpi compiler toolchain (includes GCC and Intel MPI).
 :author: Stijn De Weirdt (Ghent University)
 :author: Kenneth Hoste (Ghent University)
 """
+import re
+from distutils.version import LooseVersion
 
 from easybuild.toolchains.gcc import GccToolchain
 from easybuild.toolchains.mpi.intelmpi import IntelMPI
@@ -37,3 +39,20 @@ class Gimpi(GccToolchain, IntelMPI):
     """Compiler toolchain with GCC and Intel MPI."""
     NAME = 'gimpi'
     SUBTOOLCHAIN = GccToolchain.NAME
+
+    def is_deprecated(self):
+        """Return whether or not this toolchain is deprecated."""
+        # need to transform a version like '2018b' with something that is safe to compare with '2019'
+        # comparing subversions that include letters causes TypeErrors in Python 3
+        # 'a' is assumed to be equivalent with '.01' (January), and 'b' with '.07' (June) (good enough for this purpose)
+        version = self.version.replace('a', '.01').replace('b', '.07')
+
+        deprecated = False
+
+        # make sure a non-symbolic version (e.g., 'system') is used before making comparisons using LooseVersion
+        if re.match('^[0-9]', version):
+            # gimpi toolchains older than gimpi/2019a are deprecated since EasyBuild v4.5.0
+            if LooseVersion(version) < LooseVersion('2019'):
+                deprecated = True
+
+        return deprecated
