@@ -92,3 +92,19 @@ class Iompi(IccIfort, IntelCompilersToolchain, OpenMPI):
             IntelCompilersToolchain.set_variables(self)
         else:
             IccIfort.set_variables(self)
+
+    def is_deprecated(self):
+        """Return whether or not this toolchain is deprecated."""
+        # need to transform a version like '2018b' with something that is safe to compare with '2019'
+        # comparing subversions that include letters causes TypeErrors in Python 3
+        # 'a' is assumed to be equivalent with '.01' (January), and 'b' with '.07' (June) (good enough for this purpose)
+        version = self.version.replace('a', '.01').replace('b', '.07')
+
+        # iompi toolchains older than iompi/2019a are deprecated since EasyBuild v4.5.0
+        # make sure a non-symbolic version (e.g., 'system') is used before making comparisons using LooseVersion
+        if re.match('^[0-9]', version) and LooseVersion(version) < LooseVersion('2019'):
+            deprecated = True
+        else:
+            deprecated = False
+
+        return deprecated
