@@ -72,9 +72,11 @@ subdirs = [chr(char) for char in range(ord('a'), ord('z') + 1)] + ['0']
 for subdir in subdirs:
     __path__ = pkgutil.extend_path(__path__, '%s.%s' % (__name__, subdir))
 
-del l, subdir, subdirs
+del subdir, subdirs
+if 'char' in dir():
+    del char
 
-__path__ = __import__('pkgutil').extend_path(__path__, __name__)
+__path__ = pkgutil.extend_path(__path__, __name__)
 """
 
 
@@ -126,15 +128,17 @@ def set_up_eb_package(parent_path, eb_pkg_name, subpkgs=None, pkg_init_body=None
 def verify_imports(pymods, pypkg, from_path):
     """Verify that import of specified modules from specified package and expected location works."""
 
-    for pymod in pymods:
-        pymod_spec = '%s.%s' % (pypkg, pymod)
-
+    pymod_specs = ['%s.%s' % (pypkg, pymod) for pymod in pymods]
+    for pymod_spec in pymod_specs:
         # force re-import if the specified modules was already imported;
         # this is required to ensure that an easyblock that is included via --include-easyblocks-from-pr
         # gets preference over one that is included via --include-easyblocks
         if pymod_spec in sys.modules:
             del sys.modules[pymod_spec]
 
+    # After all modules to be reloaded have been removed, import them again
+    # Note that removing them here may delete transitively loaded modules and not import them again
+    for pymod_spec in pymod_specs:
         try:
             pymod = __import__(pymod_spec, fromlist=[pypkg])
         # different types of exceptions may be thrown, not only ImportErrors
@@ -178,8 +182,8 @@ def include_easyblocks(tmpdir, paths):
         if not os.path.exists(target_path):
             symlink(easyblock_module, target_path)
 
-    included_ebs = [x for x in os.listdir(easyblocks_dir) if x not in ['__init__.py', 'generic']]
-    included_generic_ebs = [x for x in os.listdir(os.path.join(easyblocks_dir, 'generic')) if x != '__init__.py']
+    included_ebs = sorted(x for x in os.listdir(easyblocks_dir) if x not in ['__init__.py', 'generic'])
+    included_generic_ebs = sorted(x for x in os.listdir(os.path.join(easyblocks_dir, 'generic')) if x != '__init__.py')
     _log.debug("Included generic easyblocks: %s", included_generic_ebs)
     _log.debug("Included software-specific easyblocks: %s", included_ebs)
 
