@@ -66,6 +66,7 @@ import test.framework.module_generator as mg
 import test.framework.modules as m
 import test.framework.modulestool as mt
 import test.framework.options as o
+import test.framework.output as ou
 import test.framework.parallelbuild as p
 import test.framework.package as pkg
 import test.framework.repository as r
@@ -120,7 +121,7 @@ log = fancylogger.getLogger()
 # call suite() for each module and then run them all
 # note: make sure the options unit tests run first, to avoid running some of them with a readily initialized config
 tests = [gen, bl, o, r, ef, ev, ebco, ep, e, mg, m, mt, f, run, a, robot, b, v, g, tcv, tc, t, c, s, lic, f_c,
-         tw, p, i, pkg, d, env, et, y, st, h, ct, lib, u, es]
+         tw, p, i, pkg, d, env, et, y, st, h, ct, lib, u, es, ou]
 
 SUITE = unittest.TestSuite([x.suite() for x in tests])
 res = unittest.TextTestRunner().run(SUITE)
